<?php

namespace Drupal\smallads\EventSubscriber;

use Drupal\taxonomy\Entity\Vocabulary;
use Drupal\migrate\Event\MigrateEvents;
use Drupal\migrate\Event\MigrateImportEvent;
use Drupal\migrate\Event\MigrateRollbackEvent;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Subscriber for after the categories are migrated
 *
 * This is necessary for the links and more importantly the autogenerated tasks
 * Seems like a shortcoming in the routing system, but it will certainly do for
 * this module.
 */
class PostMigrate implements EventSubscriberInterface {

  private $termStorage;

  function __construct(EntityTypeManager $entity_type_manager) {
    $this->termStorage = $entity_type_manager->getStorage('taxonomy_term');
  }

  /**
   * Move the terms from the offers_wants_categories vocab and delete it.
   */
  function onPostImport(MigrateImportEvent $event) {
     $def = $event->getMigration()->getPluginDefinition();
     if ($def['source']['plugin'] == 'd7_taxonomy_term' and $def['source']['bundle'] = 'offers_wants_categories') {
       foreach ($this->termStorage->loadByProperties(['vid' => 'offers_wants_categories']) as $term) {
         $term->vid->target_id = 'categories';
         $term->save();
       }
       if ($vocab = Vocabulary::load('offers_wants_categories')) {
         $vocab->delete();
       }
    }
  }

  function onPreRollback(MigrateRollbackEvent $event) {
    $def = $event->getMigration()->getPluginDefinition();
     if ($def['source']['plugin'] == 'd7_taxonomy_term' and $def['source']['bundle'] = 'offers_wants_categories') {
      foreach ($this->termStorage->loadByProperties(['vid' => 'categories']) as $term) {
        $term->delete();
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    //Migrate module might not be installed and we can't test for it here because
    //\Drupal::moduleHandler()->moduleExists('migrate_drupal') is not initialised yet!
    //so just replace the constants with their strings defined in Drupal\migrate\Event\MigrateEvents
    return [
      'migrate.post_import'=> ['onPostImport'], //MigrateEvents::POST_IMPORT
      'migrate.pre_rollback' => ['onPreRollback'] //MigrateEvents::PRE_ROLLBACK
    ];
  }

}
