<?php

namespace Drupal\smallads\Plugin\migrate\source\d7;

use Drupal\migrate_drupal\Plugin\migrate\source\d7\FieldableEntity;

/**
 * Drupal 7 proposition nodes in source db.
 *
 * @MigrateSource(
 *   id = "d7_smallad",
 *   source_provider = "offers_wants"
 * )
 */
class Smallad extends FieldableEntity {

  /**
   * {@inheritdoc}
   */
  public function query() {
    $want = $this->configuration['smallad_type'] == 'want';
    $query = $this->select('node', 'n');
    $query->innerJoin('offers_wants', 'ow', 'ow.nid = n.nid');
    $query->innerjoin('field_data_body', 'bod', 'n.nid = bod.entity_id');
    $query->innerjoin('field_data_offers_wants_categories', 'cat', 'n.nid = cat.entity_id');
    $query->fields('n', ['nid', 'title', 'uid', 'created', 'changed', 'language'])
      ->condition('type', 'proposition')
      ->condition('ow.want', intval($want))
      ->condition('bod.entity_type', 'node')
      ->condition('cat.entity_type', 'node');
    $query->addField('ow', 'end');
    $query->addField('bod', 'body_value');
    $query->addField('bod', 'body_format');
    $query->addField('n', 'status', 'scope');
    $query->addExpression('GROUP_CONCAT(offers_wants_categories_tid)', 'categories');
    // Group every field that isn't concatenated
    $query->groupBy('n.nid, n.title, n.uid, n.created, n.changed, n.language, ow.end, bod.body_value, bod.body_format, n.status');
    return $query;
  }

  /**
   * {@inheritdoc}
   */
  public function fields() {
    $fields = [
      'nid' => $this->t('Node ID'),
      'title' => $this->t('Title'),
      'node_uid' => $this->t('Proposition node authored by (uid)'),
      'created' => $this->t('Created timestamp'),
      'changed' => $this->t('Modified timestamp'),
      'status' => $this->t('Published'),
      'language' => $this->t('Language (fr, en, ...)'),
      'end' => $this->t('Expiry date'),
      'want' => $this->t('Smallad_type')
    ];
    return $fields;
  }

  /**
   * {@inheritdoc}
   */
  public function getIds() {
    return [
      'nid' => [
        'type' => 'integer',
        'alias' => 'n'
      ]
    ];
  }

}
